[gnumeric] collect: fix ignore blanks issues.



commit 87ceb5c2ae0fc6e64f90495a68e7826ed2c0d32e
Author: Morten Welinder <terra gnome org>
Date:   Fri Jun 11 11:55:07 2010 -0400

    collect: fix ignore blanks issues.

 NEWS                             |    1 +
 plugins/fn-financial/ChangeLog   |    5 +++++
 plugins/fn-financial/functions.c |    2 +-
 plugins/fn-math/ChangeLog        |    5 +++++
 plugins/fn-math/functions.c      |    5 +++--
 5 files changed, 15 insertions(+), 3 deletions(-)
---
diff --git a/NEWS b/NEWS
index e296b6d..37e8697 100644
--- a/NEWS
+++ b/NEWS
@@ -29,6 +29,7 @@ Morten:
 	* Fix critical when inserting graph using keys.
 	* Automate win32 help generation.
 	* Mark a sheet dirty when its tab colour is changed.  [#621191]
+	* Fix SERIESSUM issue.
 
 --------------------------------------------------------------------------
 Gnumeric 1.10.5
diff --git a/plugins/fn-financial/ChangeLog b/plugins/fn-financial/ChangeLog
index 7f59565..014048d 100644
--- a/plugins/fn-financial/ChangeLog
+++ b/plugins/fn-financial/ChangeLog
@@ -1,3 +1,8 @@
+2010-06-11  Morten Welinder  <terra gnome org>
+
+	* functions.c (gnumeric_fvschedule): Ignore blanks.  (This is the
+	same as treating as zero.)
+
 2010-06-09  Andreas J. Guelzow <aguelzow pyrshep ca>
 
 	* functions.c (gnumeric_accrint): add @{calc_method} and
diff --git a/plugins/fn-financial/functions.c b/plugins/fn-financial/functions.c
index f7ac9c5..ecd41a3 100644
--- a/plugins/fn-financial/functions.c
+++ b/plugins/fn-financial/functions.c
@@ -1981,7 +1981,7 @@ gnumeric_fvschedule (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 	pv       = value_get_as_float (argv[0]);
 	schedule = collect_floats_value (argv[1], ei->pos,
-					 0, &n, &result);
+					 COLLECT_IGNORE_BLANKS, &n, &result);
 	if (result)
 		goto out;
 
diff --git a/plugins/fn-math/ChangeLog b/plugins/fn-math/ChangeLog
index 472e04c..76c2a79 100644
--- a/plugins/fn-math/ChangeLog
+++ b/plugins/fn-math/ChangeLog
@@ -1,3 +1,8 @@
+2010-06-11  Morten Welinder  <terra gnome org>
+
+	* functions.c (gnumeric_seriessum): Ignore blanks for
+	compatibility.
+
 2010-06-10 Andreas J. Guelzow <aguelzow pyrshep ca>
 
 	* functions.c: remove superfluous spaces, inconsitent periods, etc.
diff --git a/plugins/fn-math/functions.c b/plugins/fn-math/functions.c
index 2fee72a..dc4ebb1 100644
--- a/plugins/fn-math/functions.c
+++ b/plugins/fn-math/functions.c
@@ -2510,9 +2510,10 @@ gnumeric_seriessum (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	gnm_float m = value_get_as_float (argv[2]);
 	GnmValue *result = NULL;
 	int N;
 	/* Treat blanks as 0; err on bools or strings.  */
 	gnm_float *data =
-		collect_floats_value (argv[3], ei->pos, 0, &N, &result);
+		collect_floats_value (argv[3], ei->pos,
+				      COLLECT_IGNORE_BLANKS, &N, &result);
 
 	if (result)
 		goto done;
@@ -2510,9 +2510,10 @@ gnumeric_seriessum (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	GnmValue *result = NULL;
 	int N;
-	/* Treat blanks as 0; err on bools or strings.  */
+	/* Ignore blanks; err on bools or strings.  */
 	gnm_float *data =



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]